from pydantic import BaseModel

# TODO
class BaseUserEvent(BaseModel):
    pass


__all__ = (
    "BaseUserEvent",
)
